@@ -11,7 +11,7 @@ use Time::HiRes     1.9718 ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.07';
+	$VERSION = '1.08';
 	@ISA     = 'Aspect::Modular';
 }
 
@@ -69,7 +69,7 @@ sub get_advice {
 					my $parent = $STACK[-1]->[1];
 					foreach my $z ( keys %$total ) {
 						$interval -= $total->{$z};
-						$parent->{$z} += $total->{child};
+						$parent->{$z} += $total->{$z};
 					}
 					$parent->{$zone} += $interval;
 
@@ -215,7 +215,7 @@ L<Aspect>, L<Aspect::Library::Timer>
 
 =head1 COPYRIGHT
 
-Copyright 2010 - 2011 Adam Kennedy.
+Copyright 2010 - 2012 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
